@@ -11,9 +11,9 @@ impl Grid {
                 settings.canvas_grid_color,
                 settings.canvas_grid_thickness, // radius
                 [
-                    col as f64 * settings.canvas_dot_width + settings.canvas_margin_left,
+                    col as f64 * settings.canvas_cell_size + settings.canvas_margin_left,
                     settings.canvas_margin_top,
-                    col as f64 * settings.canvas_dot_width + settings.canvas_margin_left,
+                    col as f64 * settings.canvas_cell_size + settings.canvas_margin_left,
                     settings.canvas_margin_top + canvas_size.height,
                 ],
                 c.transform,
@@ -28,9 +28,9 @@ impl Grid {
                 settings.canvas_grid_thickness, // radius
                 [
                     settings.canvas_margin_left,
-                    row as f64 * settings.canvas_dot_height + settings.canvas_margin_top,
+                    row as f64 * settings.canvas_cell_size + settings.canvas_margin_top,
                     settings.canvas_margin_left + canvas_size.width,
-                    row as f64 * settings.canvas_dot_height + settings.canvas_margin_top,
+                    row as f64 * settings.canvas_cell_size + settings.canvas_margin_top,
                 ],
                 c.transform,
                 g,
